honk/validation/meta/token
Values
pub fn validate_data(
data: json.Json,
schema: json.Json,
ctx: context.ValidationContext,
) -> Result(Nil, errors.ValidationError)
Validates token data against schema Note: Tokens are unit types used for discrimination in unions. The token value should be a string matching the fully-qualified token name (e.g., “example.lexicon.record#demoToken”). Full token name validation happens at the union/record level where the expected token name is known.
pub fn validate_schema(
schema: json.Json,
ctx: context.ValidationContext,
) -> Result(Nil, errors.ValidationError)
Validates token schema definition